@@ -7,16 +7,10 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;
 ;=============================================================================
-;    (c) copyright 2002  Kent State University
+;    (c) copyright 1999  Kent State University
 ;               all rights reserved.
-;
-; Authors:  Paul S. Wang, Kent State University
-; This work was supported by NSF/USA.
-; Permission to use this work for any purpose is granted provided that
-; the copyright notice, author and support credits above are retained.
-;
 ;=============================================================================
-(in-package "MAXIMA")
+(in-package :maxima)
 (macsyma-module mathml)
 
 ;; mcmPr-lib must be set as a directory name where your PrMathML 
@@ -98,8 +92,9 @@
              (t (cond
                   ($lamPrautolabel
                       (format mPrport "\\begin{equation}~%"))
-                  ($mPrdisplaytype (tprinc "<math>"))
-                  (t (tprinc "<math>")))
+                  ($mPrdisplaytype 
+		    (tprinc "<math  xmlns='http://www.w3.org/1998/Math/MathML'>") )
+                  (t (tprinc "<math  xmlns='http://www.w3.org/1998/Math/MathML'>")))
                 (mPr_engine mexpress 'mparen 'mparen)
                 (cond
                   ($lamPrautolabel
@@ -303,17 +298,18 @@
 (defun mPr-atom (chr)
   (cond
     ((numberp chr) (mPr-num chr))
+    ;; pwang 1/2005
+    ;; ((atom chr) (tprinc "<mi>") (tprinc (fullstrip1 chr)) (tprinc "</mi>"))
     ((get chr 'chchr) (tprinc "<mi>") 
      (tprinc (get chr 'chchr)) (tprinc "</mi>"))
     (t (tprinc "<mi>")
        (tprinc (apply 'concat
            (mapcar #'handle_rsw
-                   (rm '// (explode (fullstrip1 chr))))))
+              ;;; pwang 5/2005 (rm '// (explode (fullstrip1 chr))))))
+                   (exploden (fullstrip1 chr)))))
        (tprinc "</mi>")))
 )
 
-;; it does like remove , but it is written because when compiled, what
-;; a heck remove is added which confuse TeXetting
 (defun rm (a list)
   (do ((l list (cdr l)) (l2 nil)) ((null l) (reverse l2))
     (when (not (equal a (car l))) (setq l2 (cons (car l) l2)))))
@@ -597,13 +593,17 @@
 
 ;;      mPr-matrix handles matrix function
 (defun mPr-matrix (mexpress)
-  (row-begin "<mrow>")(tprinc "<mo>(</mo><mtable>")
+  (row-begin "<mfenced open='(' close=')'><mtable>")
   (mapc #'(lambda (arg)
 	    (row-begin "<mtr>")
             (do ((l (cdr arg) (cdr l))) ((null l) (row-end "</mtr>"))
-	      (mPr_engine (car l) 'mparen 'mparen)))
+	      (row-begin "<mtd>")
+	      (mPr_engine (car l) 'mparen 'mparen)
+	      (row-end "</mtd>")
+	      ))
         (cdr mexpress))
-  (tprinc "</mtable><mo>)</mo>") (row-end "</mrow>"))
+  (row-end "</mtable></mfenced>")
+)
 
 (defun mPr-mqapply (mexpress)
   (mPr_engine (cadr mexpress) lop 'mfunction)
@@ -684,19 +684,26 @@
 ;;      this function takes care the quotient function or "/" sign
 ;;
 (defun mPr-quotient (mexpress)
-  (tprinc "<mfrac>")
+  (row-begin "<mfrac><mrow>")
   (mPr_engine (cadr mexpress) 'mparen 'mparen)
-  (mPr_engine (caddr mexpress) 'mparen 'mparen)
-  (tprinc "</mfrac>"))
-;;      this mPr-rat is adopted from prof RJF . It performs for
-;;rat function
-(defun mPr-rat (mexpress)
+  (row-end "</mrow>")
   (row-begin "<mrow>")
-  (mPr_engine (cadr mexpress) 'mparen 'mparen)
-  (tprinc "<mo>/</mo>")
   (mPr_engine (caddr mexpress) 'mparen 'mparen)
-  (row-end "</mrow>"))
-;;      this function handle sqrt function
+  (row-end "</mrow></mfrac>"))
+
+(defun mPr-rat (mexpress) (mPr-quotient mexpress))
+
+;;      this function handles binomial coefficients
+;;
+(defun mPr-binomial(mexpress)
+    (row-begin "<mrow><mfenced open='(' close=')'><mfrac linethickness='0'><mrow>")
+       (mPr_engine (cadr mexpress) 'mparen 'mparen)
+       (tprinc "</mrow><mrow>")
+       (mPr_engine (caddr mexpress) 'mparen 'mparen)
+    (row-end  "</mrow></mfrac></mfenced></mrow>")
+)
+
+;;      this function handles sqrt
 ;;
 (defun mPr-sqrt (mexpress)
   (tprinc "<msqrt>")
@@ -838,6 +845,8 @@
 
 (setup '(%sqrt (mPrprocess mPr-sqrt) (chchr "&Sqrt;")))
 
+(setup '(%binomial (mPrprocess mPr-binomial)))
+
 (setup '(mquotient (mPrprocess mPr-quotient) (mPr-lbp 122)
             (mPr-rbp 123) (chchr "<mo>/</mo>"))) 
 
