@@ -7,16 +7,8 @@
 ;;  This program has NO WARRANTY, not even the implied warranty of
 ;;  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 
-(in-package "MAXIMA")
+(in-package :maxima)
 
-;; This file contains some functions to read and write data files.
-;; Data files can contain integers, rationals, floats, complex,
-;; strings (in double quotes), and symbols. The case of a symbol
-;; (upper, lower, or mixed) is preserved, thus ``FOO'', ``Bar'',
-;; and ``baz'' in a data file are ``FOO'', ``Bar'', and ``baz'' in
-;; Maxima. The entire file is read to construct one object;
-;; partial reads are not supported.
-;;
 ;; Read functions:
 ;;   M: read_matrix (file_name, sep_ch_flag)$
 ;;   read_lisp_array (file_name, A, sep_ch_flag)$
@@ -26,54 +18,9 @@
 ;;   L: read_list (file_name, sep_ch_flag)$
 ;;
 ;; Write function:
-;;   write_data(X, file_name, sep_ch_flag)$
-;;
-;; Notes: (1) sep_ch_flag tells what to use to separate elements.
-;; It is an optional argument for all read & write functions.
-;; Two values are understood: 'CSV for comma separated values,
-;; and 'SPACE for space separated values. If the file name ends
-;; in ".csv", 'CSV is assumed unless sep_ch_flag is explicitly specified.
-;; If not ".csv" and not specified, 'SPACE is assumed.
-;;
-;; (2) READ_MATRIX infers the size of the matrix from the input data.
-;;
-;; (3) READ_LISP_ARRAY and READ_MAXIMA_ARRAY require that the array
-;; be declared by MAKE_ARRAY or ARRAY (respectively) before calling
-;; the read function. (This obviates the need to infer the array 
-;; dimensions, which could be a hassle for arrays with multiple dimensions.)
-;;
-;; (4) READ_LISP_ARRAY and READ_MAXIMA_ARRAY do not check to see that the 
-;; input file conforms in some way to the array dimensions; the input
-;; is read as a flat list, then the array is filled using FILLARRAY.
-;;
-;; (5) READ_HASHED_ARRAY treats the first item on a line as a
-;; hash key, and makes the remainder of the line into a list:
-;; reading "567 12 17 32 55" is equivalent to A[567]: [12, 17, 32, 55]$
-;; Lines need not have the same numbers of elements.
-;;
-;; (6) READ_NESTED_LIST makes a list which has a sublist for each
-;; line of input. Lines need not have the same numbers of elements.
-;; Empty lines are -not- ignored: an empty line yields an empty sublist.
-;; 
-;; (7) READ_LIST reads all input into a flat list.
-;; READ_LIST ignores end-of-line characters.
-;;
-;; (8) WRITE_DATA figures out what kind of object is X and
-;; hands it off to an appropriate function to write it out.
-;;
-;; (9) WRITE_DATA writes matrices in row-major form,
-;; with one line per row.
-;;
-;; (10) WRITE_DATA writes Lisp and Maxima declared arrays in
-;; row-major form, with a new line at the end of every slab.
-;; Higher-dimensional slabs are separated by additional new lines.
-;;
-;; (11) WRITE_DATA writes hashed arrays with a key followed by
-;; the associated list on each line.
-;;
-;; (12) WRITE_DATA writes a nested list with each sublist on one line.
-;;
-;; (13) WRITE_DATA writes a flat list all on one line.
+;;   write_data (X, file_name, sep_ch_flag)$
+
+;; See numericalio.texi for a lengthier description.
 
 ;; -------------------- read functions --------------------
 
@@ -96,7 +43,7 @@
   (with-open-file (in file-name :if-does-not-exist nil)
     (cond
       ((not (null in))
-        (let ((sep-ch (get-sep-ch sep-ch-flag file-name)))
+        (let (key L (sep-ch (get-input-sep-ch sep-ch-flag file-name)))
           (loop
             (setq L (read-line in nil 'eof))
             (if (eq L 'eof) (return))
@@ -116,7 +63,7 @@
     (setq file-name (require-string file-name))
     (with-open-file (in file-name :if-does-not-exist nil)
       (cond ((not (null in))
-          (let ((sep-ch (get-sep-ch sep-ch-flag file-name)))
+          (let ((sep-ch (get-input-sep-ch sep-ch-flag file-name)))
             (loop
               (setq L (read-line in nil 'eof))
               (if (eq L 'eof) (return (cons '(mlist simp) A)))
@@ -129,7 +76,7 @@
     (setq file-name (require-string file-name))
     (with-open-file (in file-name :if-does-not-exist nil)
       (cond ((not (null in))
-          (let ((sep-ch (get-sep-ch sep-ch-flag file-name)))
+          (let ((sep-ch (get-input-sep-ch sep-ch-flag file-name)))
             (loop
               (setq L (read-line in nil 'eof))
               (if (eq L 'eof) (return (cons '(mlist simp) A)))
@@ -151,15 +98,15 @@
           ((eq token 'eof)
            (cond
              ((not (null sign))
-              (format t "numericalio: trailing sign (~S) at end of line; strange, but just eat it." sign)))
+              (format t "numericalio: trailing sign (~S) at end of line; strange, but just eat it.~%" sign)))
            (cond
              ((eq sep-ch #\space)
               (return (cons '(mlist) LL)))
              (t
                (return (cons '(mlist) (appropriate-append L LL)))))))
         (cond
-          ((or (eq token '|$-|) (eq token '|$+|))
-           (setq sign (cond ((eq token '|$-|) -1) (t 1))))
+          ((or (eq token '$-) (eq token '$+))
+           (setq sign (cond ((eq token '$-) -1) (t 1))))
           (t
             (cond
               ((not (null sign))
@@ -176,23 +123,13 @@
                   (t
                     (setq LL (append LL (list token)))))))))))))
 
+
 (defun appropriate-append (L LL)
   (cond
     ((null LL) (append L '(nil)))
     ((= (length LL) 1) (append L LL))
     (t (append L (list (append '((mlist)) LL))))))
 
-(defun lisp-to-maxima (x)
-  (cond ((null x) x)
-    ((eq x t) x)
-    ((symbolp x) (makealias x))
-    ((and (rationalp x) (not (integerp x)))
-      `((rat simp) ,(numerator x) ,(denominator x)))
-    ((complexp x)
-      `((mplus simp) ,(lisp-to-maxima (realpart x)) 
-        ((mtimes simp) ,(lisp-to-maxima (imagpart x)) $%i)))
-    (t x)))
-
 
 ;; -------------------- write functions -------------------
 
@@ -210,18 +147,24 @@
     (t (merror "write_data: don't know what to do with a ~M" (type-of X))))
   '$done)
 
+; Thanks to William Bland on comp.lang.lisp for help writing this macro.
+(defmacro with-open-file-appropriately ((out fname) &body body)
+  `(with-open-file (,out ,fname :direction :output
+    :if-exists (if (or (eq $file_output_append '$true) (eq $file_output_append t)) :append :supersede)
+    :if-does-not-exist :create)
+    ,@body))
 
 (defun write-matrix (M file-name &optional sep-ch-flag)
   (setq file-name (require-string file-name))
-  (with-open-file (out file-name :direction :output :if-exists :supersede)
-    (let ((sep-ch (get-sep-ch sep-ch-flag file-name)))
+  (with-open-file-appropriately (out file-name)
+    (let ((sep-ch (get-output-sep-ch sep-ch-flag file-name)))
       (mapcar #'(lambda (x) (write-list-lowlevel (cdr x) out sep-ch)) (cdr M)))))
 
 
 (defun write-lisp-array (A file-name &optional sep-ch-flag)
   (setq file-name (require-string file-name))
-  (with-open-file (out file-name :direction :output :if-exists :supersede)
-    (let ((sep-ch (get-sep-ch sep-ch-flag file-name)) (d (array-dimensions A)))
+  (with-open-file-appropriately (out file-name)
+    (let ((sep-ch (get-output-sep-ch sep-ch-flag file-name)) (d (array-dimensions A)))
       (write-lisp-array-helper A d '() out sep-ch))))
 
 
@@ -243,10 +186,10 @@
 
 
 (defun write-hashed-array (A file-name &optional sep-ch-flag)
-  (let ((keys (cdddr (meval (list '($arrayinfo) A)))) (L))
   (setq file-name (require-string file-name))
-    (with-open-file (out file-name :direction :output :if-exists :supersede)
-      (let ((sep-ch (get-sep-ch sep-ch-flag file-name)))
+  (let ((keys (cdddr (meval (list '($arrayinfo) A)))) (L))
+    (with-open-file-appropriately (out file-name)
+      (let ((sep-ch (get-output-sep-ch sep-ch-flag file-name)))
         (loop
           (if (not keys) (return))
           (setq L ($arrayapply A (car keys)))
@@ -257,8 +200,8 @@
 
 (defun write-list (L file-name &optional sep-ch-flag)
   (setq file-name (require-string file-name))
-  (with-open-file (out file-name :direction :output :if-exists :supersede)
-    (let ((sep-ch (get-sep-ch sep-ch-flag file-name)))
+  (with-open-file-appropriately (out file-name)
+    (let ((sep-ch (get-output-sep-ch sep-ch-flag file-name)))
       (write-list-lowlevel (cdr L) out sep-ch))))
 
 
@@ -270,52 +213,34 @@
         (let ((e (pop l)))
           (cond (($listp e)
               (write-list-lowlevel (cdr e) stream sep-ch))
-            (t (my-mgrind e stream)
+            (t (mgrind e stream)
               (cond ((null L) (terpri stream))
                 (t (write-char sep-ch stream)))))))))
   (finish-output stream))
 
 
-(defun my-mgrind (x fs)
-  (setq x (maybe-convert-complex x))
-  (cond ((complexp x) (format fs "~S" x))
-    (t (mgrind x fs))))
-
-
-(defun maybe-convert-complex (x)
-  (cond ((not ($freeof '$%i x))
-      (let ((xr ($realpart x)) (xi ($imagpart x)))
-        (setq xr (maybe-convert-rat xr))
-        (setq xi (maybe-convert-rat xi))
-        (if (and (numberp xr) (numberp xi))
-          (setq x (complex xr xi))))))
-  x)
-
-
-(defun maybe-convert-rat (x)
-  (cond ((and ($ratnump x) (not (integerp x)))
-      (setq x (/ (nth 1 x) (nth 2 x)))))
-  x)
-
-
-(defun maybe-convert-symbol (x)
-  (cond ((and (symbolp x) (not (null x)) (not (eq x t)))
-      (setq x (stripdollar x))))
-  x)
-  
-
-(defun get-sep-ch (sep-ch-flag file-name)
+(defun get-input-sep-ch (sep-ch-flag file-name)
   (cond
-    ((eq sep-ch-flag '$csv) '|$,|)
+    ((eq sep-ch-flag '$tab)
+     (format t "numericalio: separator flag ``tab'' not recognized for input; assume ``space'' instead.~%")
+     #\space)
+    (t (get-output-sep-ch sep-ch-flag file-name))))
+
+
+(defun get-output-sep-ch (sep-ch-flag file-name)
+  (cond
+    ((eq sep-ch-flag '$space) #\space)
+    ((eq sep-ch-flag '$tab) #\tab)
+    ((or (eq sep-ch-flag '$comma) (eq sep-ch-flag '$csv)) '$\,) ; '$csv is backwards compatibility ... sigh
     ((eq sep-ch-flag '$pipe) '$\|)
-    ((eq sep-ch-flag '$space) '#\space)
+    ((eq sep-ch-flag '$semicolon) '$\;)
 
     ((null sep-ch-flag)
-      (cond ((equal (pathname-type file-name) "csv") '|$,|)
-        (t '#\space)))
+      (cond ((equal (pathname-type file-name) "csv") '$\,)
+        (t #\space)))
     (t
-      (format t "numericalio: separator flag ~S not recognized; assume ``space''" (stripdollar sep-ch-flag))
-      '#\space)))
+      (format t "numericalio: separator flag ~S not recognized; assume ``space''.~%" (stripdollar sep-ch-flag))
+      #\space)))
 
 
 (defun require-string (s)
