@@ -15,7 +15,7 @@
 
 ;	** (c) Copyright 1979 Massachusetts Institute of Technology **
 
-(in-package "MAXIMA")
+(in-package :maxima)
 
 
 
