@@ -1,7 +1,7 @@
 ;;;  -*- LISP -*-
 ;;;	** (c) Copyright 1979 Massachusetts Institute of Technology **
 
-(in-package "MAXIMA")
+(in-package :maxima)
 
 (macsyma-module hyp)
 
