@@ -8,7 +8,7 @@
 ;;;     (c) Copyright 1982 Massachusetts Institute of Technology         ;;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-(in-package "MAXIMA")
+(in-package :maxima)
 
 
 (macsyma-module merror)
@@ -30,7 +30,7 @@
   "Signals a Maxima user error."
   (apply #'merror (fstringc l)))
 
-(defmvar $error_size 10.
+(defmvar $error_size 60.
   "Expressions greater in SOME size measure over this value
   are replaced by symbols {ERREXP1, ERREXP2,...} in the MAXIMA-ERROR
   display, the symbols being set to the expressions, so that one can
@@ -38,6 +38,12 @@
   this variable may be determined by factors of terminal speed and type.")
 
 (defun error-size (exp)
+  ; RATDISREP the argument in case it's a CRE. Ugh.
+  ; But RATDISREP simplifies its argument, which is a no-no if we got here
+  ; because some simplification code is complaining, so inhibit simplification. Double ugh.
+  (let (($simp nil))
+    (setq exp (ratdisrep exp)))
+
   (if (atom exp) 0
       (do ((l (cdr exp) (cdr l))
 	   (n 1 (f1+ (f+ n (error-size (car l))))))
