@@ -9,7 +9,7 @@
 ;;;       (c) Copyright 1982 Massachusetts Institute of Technology       ;;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-(in-package "MAXIMA")
+(in-package :maxima)
 (macsyma-module mload)
 
 ;; I decided to move most of the file hacking utilities I used in TRANSL to
@@ -829,12 +829,12 @@
 	   (or (streamp *collect-errors*)
 	       (close error-log)))))
   (cond ((null all-differences)
-	 (format t "~a/~a tests passed." num-problems num-problems) '((mlist)))
+	 (format t "~a/~a tests passed.~%" num-problems num-problems) '((mlist)))
 	(t (progn
-	     (format t "~%~a/~a tests passed." 
+	     (format t "~%~a/~a tests passed.~%" 
 		     (- num-problems (length all-differences)) num-problems)
 	     (let ((s (if (> (length all-differences) 1) "s" "")))
-	       (format t "~%The following ~A problem~A failed: ~A" 
+	       (format t "~%The following ~A problem~A failed: ~A~%" 
 		       (length all-differences) s all-differences))
 	     `((mlist),filename ,@ all-differences)))))
 	   
@@ -886,30 +886,32 @@
   (atomchk paths '$file_search t)
   (new-file-search (string name) (cdr paths)))
 
-(defun new-file-search (name template &aux lis temp)
+(defun new-file-search (name template)
   (cond ((probe-file name))
 	((atom template)
-	 (setq template (namestring ($filename_merge template  name)))
-					;(print (list 'template template))
-	 (setq lis 
-	       (loop for w in (split-string template "{}")
-		      when (null (position #\, w))
-		      collect w
-		      else
-		      collect (split-string w ",")))
-	 (new-file-search1 "" lis))
-	(t (loop for v in template
-		  when (setq temp (new-file-search name v))
-		  do (return temp)))))
+	 (let ((lis (loop for w in (split-string template "{}")
+			  when (null (position #\, w))
+			  collect w
+			  else
+			  collect (split-string w ","))))
+	   (new-file-search1 name "" lis)))
+	(t
+	 (let ((temp nil))
+	   (loop for v in template
+		 when (setq temp (new-file-search name v))
+		 do (return temp))))))
 
-(defun new-file-search1 (begin lis )
-  (cond ((null lis) (if (probe-file begin) begin nil))
+(defun new-file-search1 (name begin lis)
+  (cond ((null lis)
+	 (let ((file (namestring ($filename_merge begin name))))
+	   (if (probe-file file) file nil)))
 	((atom (car lis))
-	 (new-file-search1 (if begin
+	 (new-file-search1 name
+			   (if begin
 			       ($sconcat begin (car lis)) (car lis))
 			   (cdr lis)))
 	(t (loop for v in (car lis) with tem
-		  when (setq tem  (new-file-search1 begin (cons v (cdr lis))))
+		  when (setq tem  (new-file-search1 name begin (cons v (cdr lis))))
 		  do (return tem)))))
 
 (defun save-linenumbers (&key (c-lines t) d-lines (from 1) (below $linenum) a-list
@@ -925,14 +927,14 @@
 		      (format nil "~a:~a:~a" (car tem) (cadr tem) (caadr tem)))
 	    )
     (loop for i in a-list
-	   when (and c-lines (boundp (setq input-symbol (intern (format nil "$C~A" i)))))
+	   when (and c-lines (boundp (setq input-symbol (intern (format nil "$~A~A" '#:c i)))))
 	   do
 	   (format st "~% C~3A;  "   i)
 	   (mgrind (symbol-value input-symbol)
 		   st)
 	   (format st ";")
 	   when (and d-lines
-		     (boundp (setq input-symbol (intern (format nil "$D~A" i)))))
+		     (boundp (setq input-symbol (intern (format nil "$~A~A" '#:d i)))))
 	   do
 	   (format st "~% D~3A:  "   i)
 	   (mgrind (symbol-value
@@ -953,35 +955,58 @@
 
   
   
-(defvar *testsuite-files* nil)
+(defmvar $testsuite_files nil)
 
 (defvar *maxima-testsdir*)
 
-(defun $run_testsuite (&optional (show-known-bugs nil) (show-all nil)) 
+(defun intersect-tests (tests)
+  ;; If TESTS is non-NIL, we assume it's a Maxima list of (maxima)
+  ;; strings naming the tests we want to run.  They must match the
+  ;; file names in $testsuite_files.  We ignore any items that aren't
+  ;; in $testsuite_files.
+  (mapcar #'(lambda (x)
+	      (if (symbolp x)
+		  (subseq (print-invert-case x) 1)
+		  x))
+	  (cond (tests
+		 (intersection (cdr $testsuite_files)
+			       (cdr tests)
+			       :key #'(lambda (x)
+					(maxima-string (if (listp x)
+							   (second x)
+							   x)))
+			       :test #'string=))
+		(t
+		 (cdr $testsuite_files)))))
+
+(defun $run_testsuite (&optional (show-known-bugs nil) (show-all nil) (tests nil)) 
   (let ((test-file)
 	(expected-failures))
     (setq *collect-errors* nil)
-    (load (concatenate 'string *maxima-testsdir* "/" "testsuite.lisp"))
+    (unless $testsuite_files
+      (load (concatenate 'string *maxima-testsdir* "/" "testsuite.lisp")))
     (let ((error-break-file)
-	  (testresult))
+	  (testresult)
+	  (tests-to-run (intersect-tests tests)))
       (time 
-       (loop with errs = '() for testentry in *testsuite-files*
+       (loop with errs = '() for testentry in tests-to-run
 	      do
 	      (if (atom testentry)
 		  (progn
 		    (setf test-file testentry)
 		    (setf expected-failures nil))
 		  (progn
-		    (setf test-file (first testentry))
-		    (setf expected-failures (rest testentry))))
+		    (setf test-file (second testentry))
+		    (setf expected-failures (cddr testentry))))
   
-	      (format t "~%Running tests in ~a: " test-file)
+	    (format t "Running tests in ~a: " (if (symbolp test-file)
+						    (subseq (print-invert-case test-file) 1)
+						    test-file))
 	      (or (errset
 		   (progn
 		     (setq testresult 
 			   (rest (test-batch
-				  (format nil "~a/~a" 
-					  *maxima-testsdir* test-file)
+				  ($file_search test-file $file_search_tests)
 				  expected-failures
 				  :show-expected show-known-bugs
 				  :show-all show-all)))
