@@ -1,12 +1,12 @@
-;;; Compiled by f2cl version 2.0 beta Date: 2005/06/20 01:53:39 
-;;; Using Lisp CMU Common Lisp Snapshot 2005-06 (19B)
+;;; Compiled by f2cl version 2.0 beta Date: 2006/01/31 15:11:05 
+;;; Using Lisp CMU Common Lisp Snapshot 2006-01 (19C)
 ;;; 
 ;;; Options: ((:prune-labels nil) (:auto-save t) (:relaxed-array-decls t)
 ;;;           (:coerce-assigns :as-needed) (:array-type ':array)
 ;;;           (:array-slicing t) (:declare-common nil)
 ;;;           (:float-format double-float))
 
-(in-package "SLATEC")
+(in-package :slatec)
 
 
 (let ((x
@@ -24,8 +24,7 @@
           resasc momcom chebmo)
     (declare (type (array double-float (*)) chebmo)
              (type f2cl-lib:integer4 momcom neval ksave maxp1 nrmom integr)
-             (type double-float resasc resabs abserr result omega b a)
-             (type (function (double-float) (values double-float &rest t)) f))
+             (type double-float resasc resabs abserr result omega b a))
     (f2cl-lib:with-multi-array-data
         ((chebmo double-float chebmo-%data% chebmo-%offset%))
       (prog ((cheb12 (make-array 13 :element-type 'double-float))
