@@ -1,12 +1,12 @@
-;;; Compiled by f2cl version 2.0 beta Date: 2005/06/20 01:53:39 
-;;; Using Lisp CMU Common Lisp Snapshot 2005-06 (19B)
+;;; Compiled by f2cl version 2.0 beta Date: 2006/01/31 15:11:05 
+;;; Using Lisp CMU Common Lisp Snapshot 2006-01 (19C)
 ;;; 
 ;;; Options: ((:prune-labels nil) (:auto-save t) (:relaxed-array-decls t)
 ;;;           (:coerce-assigns :as-needed) (:array-type ':array)
 ;;;           (:array-slicing t) (:declare-common nil)
 ;;;           (:float-format double-float))
 
-(in-package "SLATEC")
+(in-package :slatec)
 
 
 (let ((wg
@@ -34,8 +34,7 @@
   (declare (type (array double-float (8)) wgk xgk wg))
   (defun dqk15i (f boun inf a b result abserr resabs resasc)
     (declare (type f2cl-lib:integer4 inf)
-             (type double-float resasc resabs abserr result b a boun)
-             (type (function (double-float) (values double-float &rest t)) f))
+             (type double-float resasc resabs abserr result b a boun))
     (f2cl-lib:with-multi-array-data
         nil
       (prog ((fv1 (make-array 7 :element-type 'double-float))
