@@ -1,12 +1,12 @@
-;;; Compiled by f2cl version 2.0 beta Date: 2005/06/20 01:53:39 
-;;; Using Lisp CMU Common Lisp Snapshot 2005-06 (19B)
+;;; Compiled by f2cl version 2.0 beta Date: 2006/01/31 15:11:05 
+;;; Using Lisp CMU Common Lisp Snapshot 2006-01 (19C)
 ;;; 
 ;;; Options: ((:prune-labels nil) (:auto-save t) (:relaxed-array-decls t)
 ;;;           (:coerce-assigns :as-needed) (:array-type ':array)
 ;;;           (:array-slicing t) (:declare-common nil)
 ;;;           (:float-format double-float))
 
-(in-package "SLATEC")
+(in-package :slatec)
 
 
 (let ((wg
@@ -60,8 +60,7 @@
   (declare (type (array double-float (26)) wgk xgk)
            (type (array double-float (13)) wg))
   (defun dqk51 (f a b result abserr resabs resasc)
-    (declare (type double-float resasc resabs abserr result b a)
-             (type (function (double-float) (values double-float &rest t)) f))
+    (declare (type double-float resasc resabs abserr result b a))
     (f2cl-lib:with-multi-array-data
         nil
       (prog ((fv1 (make-array 25 :element-type 'double-float))
