@@ -1,19 +1,19 @@
-;;; Compiled by f2cl version 2.0 beta Date: 2005/06/20 01:53:39 
-;;; Using Lisp CMU Common Lisp Snapshot 2005-06 (19B)
+;;; Compiled by f2cl version 2.0 beta Date: 2006/01/31 15:11:05 
+;;; Using Lisp CMU Common Lisp Snapshot 2006-01 (19C)
 ;;; 
 ;;; Options: ((:prune-labels nil) (:auto-save t) (:relaxed-array-decls t)
 ;;;           (:coerce-assigns :as-needed) (:array-type ':simple-array)
 ;;;           (:array-slicing nil) (:declare-common nil)
 ;;;           (:float-format double-float))
 
-(in-package "SLATEC")
+(in-package :slatec)
 
 
 (let* ((lentab 10))
   (declare (type f2cl-lib:integer4 lentab))
-  (let ((libtab (f2cl-lib:f2cl-init-string ((+ 1 (- lentab 1))) (8)))
-        (subtab (f2cl-lib:f2cl-init-string ((+ 1 (- lentab 1))) (8)))
-        (mestab (f2cl-lib:f2cl-init-string ((+ 1 (- lentab 1))) (20)))
+  (let ((libtab (f2cl-lib:f2cl-init-string ((+ 1 (- lentab 1))) (8) nil))
+        (subtab (f2cl-lib:f2cl-init-string ((+ 1 (- lentab 1))) (8) nil))
+        (mestab (f2cl-lib:f2cl-init-string ((+ 1 (- lentab 1))) (20) nil))
         (nertab (make-array lentab :element-type 'f2cl-lib:integer4))
         (levtab (make-array lentab :element-type 'f2cl-lib:integer4))
         (kount (make-array lentab :element-type 'f2cl-lib:integer4))
